@@ -6,7 +6,8 @@ function (x, y, phases, arrow.size=0.05, arrow.size.head=0.05, arrow.lwd=2, arro
   asp<-par("pin")[2]/par("pin")[1] 
   dx=cos(phases)*arrow.size
   dy=sin(phases)*arrow.size*asp
+
   suppressWarnings(
-    arrows(x-dx, y-dy, x + dx, y + dy, length=arrow.size.head, lwd=arrow.lwd, 
+    arrows(x, y, x + dx, y + dy, length=arrow.size.head, lwd=arrow.lwd, 
            col=arrow.col, code=2))
 }
